@@ -1,13 +1,12 @@
 from firebase_admin import firestore
 
-from mojec_core.app.models import WorkOrder
 from mojec_core.utils import log_exception
 
 
 class FirebaseManager:
     db = firestore.client()
 
-    def assign_workorder(self, wo: WorkOrder):
+    def assign_workorder(self, wo):
         try:
             doc_ref = self.db.collection('WORKORDERS').document(
                 wo.uid.__str__())
