@@ -1,12 +1,14 @@
 from django.db import models
 
 from .base import BaseModelAbstract
-from .disco import Disco
+from .disco import Disco, BusinessUnit
 
 
 class MeterRequest(BaseModelAbstract, models.Model):
     disco = models.ForeignKey(Disco, models.SET_NULL,
                               blank=True, null=True)
+    businessUnit = models.ForeignKey(BusinessUnit, models.SET_NULL,
+                                     blank=True, null=True)
     quantity = models.IntegerField(default=1)
     phone = models.CharField(max_length=11, blank=True, null=True)
     account = models.CharField(max_length=255, blank=True, null=True)
