@@ -1,3 +1,5 @@
+import time
+
 from django.db import models
 
 from .user_address import UserAddress
@@ -85,6 +87,11 @@ class WorkOrder(BaseModelAbstract, models.Model):
                                           blank=True, null=True)
     agentArrivedAt = models.DateTimeField(db_column='agentArrivedAt',
                                           blank=True, null=True)
+    
+    def save(self, keep_deleted=False, **kwargs):
+        if not self.orderId:
+            self.orderId = str(time.time()).split('.')[0]
+        super(WorkOrder, self).save(keep_deleted=keep_deleted, **kwargs)
 
     class Meta:
         db_table = 'WorkOrders'
